aboutsummaryrefslogtreecommitdiff
path: root/src/RWADBusAdaptor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/RWADBusAdaptor.cpp')
-rw-r--r--src/RWADBusAdaptor.cpp24
1 files changed, 19 insertions, 5 deletions
diff --git a/src/RWADBusAdaptor.cpp b/src/RWADBusAdaptor.cpp
index 8fd9e7d..381faca 100644
--- a/src/RWADBusAdaptor.cpp
+++ b/src/RWADBusAdaptor.cpp
@@ -1,6 +1,7 @@
/*
* This file was generated by qdbusxml2cpp version 0.8
- * Command line was: qdbusxml2cpp -i RWADBusAdaptor.h -p :RWADBusAdaptor.cpp rwa.xml
+ * Command line was: qdbusxml2cpp -i src/RWADBusAdaptor.h -p :src/RWADBusAdaptor.cpp rwa.xml
+ * rwa.xml is the xml output of the Introspect D-Bus method
*
* qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
*
@@ -9,17 +10,30 @@
* before re-generating it.
*/
-#include "RWADBusAdaptor.h"
+#include "src/RWADBusAdaptor.h"
/*
* Implementation of interface class OrgArcticaProjectRWAInterface
*/
-OrgArcticaProjectRWAInterface::OrgArcticaProjectRWAInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
+OrgArcticaProjectRWASupportSessionServiceInterface::OrgArcticaProjectRWASupportSessionServiceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
: QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}
-OrgArcticaProjectRWAInterface::~OrgArcticaProjectRWAInterface()
+OrgArcticaProjectRWASupportSessionServiceInterface::~OrgArcticaProjectRWASupportSessionServiceInterface()
+{
+}
+
+/*
+ * Implementation of interface class OrgFreedesktopDBusIntrospectableInterface
+ */
+
+OrgFreedesktopDBusIntrospectableInterface::OrgFreedesktopDBusIntrospectableInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
+ : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
+{
+}
+
+OrgFreedesktopDBusIntrospectableInterface::~OrgFreedesktopDBusIntrospectableInterface()
{
}
@@ -9,17 +10,30 @@
/*
- * Implementation of interface class OrgArcticaProjectRWAInterface
+ * Implementation of interface class OrgArcticaProjectRWASupportSessionServiceInterface
*/